@@ -210,14 +210,28 @@ sub DESTROY {
 }
 
 
+
+1
+
+__END__
+=pod
+
 =head1 NAME
 
 ElasticSearchX::Autocomplete::Indexer
 
+=head1 VERSION
+
+version 0.06
+
 =head1 DESCRIPTION
 
 To follow
 
+=head1 NAME
+
+ElasticSearchX::Autocomplete::Indexer
+
 =head1 SEE ALSO
 
 L<ElasticSearchX::Autocomplete>, L<http://www.elasticsearch.org>
@@ -234,7 +248,16 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.7 or,
 at your option, any later version of Perl 5 you may have available.
 
+=head1 AUTHOR
+
+Clinton Gormley <drtech@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Clinton Gormley.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1
